#!/bin/sh

OLDSTR='ServiceTypes=.\+'
NEWSTR='ServiceTypes=KFileItemAction\/Plugin,application\/octet-stream,inode\/directory'

KDIFF3_DESKTOP_FILE='kdiff3fileitemaction.desktop'
KDIFF="`which kdiff3`"

##
##
##

function enable_kdiff3_dircmp()
{
   kdiffversion=`$KDIFF --version | awk '/kdiff3/ {print $2}'`
   kdiffmajorver=`echo "$kdiffversion" | cut -d'.' -f1`
   kdiffminormicrover=`echo "$kdiffversion" | cut -d'.' -f2,3`

   if [ `echo "$kdiffmajorver < 1" | bc` -eq 1 ]; then
      if [ `echo "$kdiffminormicrover < 9.96" | bc` -eq 1 ]; then
         echo "------------------------------------"
         echo "Error: KDiff3 >= 0.9.96 is required."
         echo "------------------------------------"
         exit 1
      fi
   fi

   # kde <major.minor> version
   kdever=`kde-open -v | awk '/Platform/ {print $4}' | cut -d. -f1,2`

   if [ `echo "$kdever < 4.6" | bc` -eq 1 ];then
      echo "------------------------------------------------------"
      echo "Error: KDiff3FileItemActionPlugin requires KDE >= 4.6."
      echo "------------------------------------------------------"
      exit 1
   fi

   # get kde services path
   [ -z "$1" ] && kdeservicespath="`kde4-config --path services`" \
               || kdeservicespath=$1

   ORIGIFS=$IFS; IFS=':'
   found=0

   for i in $kdeservicespath
   do
      # full name
      deskfile=$i/$KDIFF3_DESKTOP_FILE

      if [ -e "$deskfile" ]; then
         found=1
         ownerid=`stat -c %u $deskfile`

         if [ `id -u` -ne $ownerid ]; then
            echo "------------------------------------------------------------"
            echo "Error: it seems you don't have permissions to write the file"
            echo "(<$deskfile>)."
            echo "Probably you need to run this script as a 'root' user."
            echo "------------------------------------------------------------"
         else
            if grep 'ServiceTypes=.\+directory' $deskfile >/dev/null; then
               echo "---------------------------------------------------------"
               echo "It seems that nothing needs to be changed in the file"
               echo "<$deskfile>."
               echo "---------------------------------------------------------"
            else
               cp $deskfile $deskfile.kdiff3dircmp.backup
               sed -i -e "s/$OLDSTR/$NEWSTR/" $deskfile
               echo "--------------------------------------------------------"
               echo "<$deskfile>"
               echo "has been changed and backed up."
               echo "Run <restore.sh [path]> to undone the changes."
               echo "--------------------------------------------------------"
            fi
         fi
      fi
   done

   IFS=$ORIGIFS
   if [ $found -ne 1 ]; then
      echo "-----------------------------------------------------------"
      echo "Error: cannot find any file <$KDIFF3_DESKTOP_FILE>."
      echo "-----------------------------------------------------------"
      exit 1
   fi
}

##
## Main
##

enable_kdiff3_dircmp $1
exit 0